package convertquery

import "fmt"

func createConstraints(constraints *[]constraintStruct, isRelation bool, onlyEdge bool) *string {
	s := ""
	if len(*constraints) == 0 {
		return &s
	}

	newLineStatement := "\tFILTER"

	for _, v := range *constraints {
		s += fmt.Sprintf("%v %v \n", newLineStatement, *createConstraintLine(&v, isRelation, onlyEdge))
		newLineStatement = "\tAND"
	}

	return &s
}

func createConstraintLine(constraint *constraintStruct, isRelation bool, onlyEdge bool) *string {
	var (
		match string
		value string
		line  string
	)

	//Wicked switches letsgo
	switch constraint.DataType {
	case "text":
		value = fmt.Sprintf("\"%s\"", constraint.Value)
		switch constraint.MatchType {
		case "contains":
			match = "IN"
		case "startswith":
			match = "LIKE"
			value = fmt.Sprintf("\"%s%%\"", constraint.Value)
		case "endswith":
			match = "LIKE"
			value = fmt.Sprintf("\"_%s\"", constraint.Value)
		default: //exact
			match = "=="
		}
	case "number":
		value = constraint.Value
		switch constraint.MatchType {
		case "GT":
			match = ">"
		case "LT":
			match = "<"
		case "GET":
			match = ">="
		case "LET":
			match = "<="
		default: //EQ
			match = "=="
		}
	default: /*bool*/
		value = constraint.Value
		switch constraint.MatchType {
		case "NEQ":
			match = "!="
		default: //EQ
			match = "=="
		}
	}

	if isRelation && !onlyEdge {
		line = fmt.Sprintf("p.edges[*].%s ALL %s %s", constraint.Attribute, match, value)
	} else {
		line = fmt.Sprintf("x.%s %s %s", constraint.Attribute, match, value)
	}
	return &line
}
